@@ -1,4 +1,3 @@
-
 /*
  *  devinfo.h
  *
@@ -37,18 +36,17 @@
 #include "devicelisting.h"
 #include "infopanel.h"
 
-
 class DevInfoPlugin : public KCModule
 {
-  Q_OBJECT
-  
-  public:
-    DevInfoPlugin(QWidget *parent, const QVariantList &);
+    Q_OBJECT
+
+public:
+    explicit DevInfoPlugin(QWidget *parent, const QVariantList &);
     ~DevInfoPlugin();
-    
-    void updateStatus(const QString uid);
-    
-  private:
+
+    void updateStatus(const QString &uid);
+
+private:
     QGridLayout *layout;
     QLabel *udiStatus;
 };
