@@ -3,7 +3,7 @@
  *
  *  Copyright (C) 2008 Ivo Anjo <knuckles@gmail.com>
  *  Copyright (C) 2004 Ilya Korniyko <k_ilya@ukr.net>
- *  Adapted from Brian Paul's glxinfo from Mesa demos (http://www.mesa3d.org)
+ *  Adapted from Brian Paul's glxinfo from Mesa demos (https://www.mesa3d.org/)
  *  Copyright (C) 1999-2002 Brian Paul
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -97,7 +97,7 @@ KCMOpenGL::KCMOpenGL(QWidget *parent, const QVariantList &)
     about->addAuthor(i18n("Ivo Anjo"), QString(), QStringLiteral("knuckles@gmail.com"));
     about->addAuthor(i18n("Ilya Korniyko"), QString(), QStringLiteral("k_ilya@ukr.net"));
     about->addCredit(i18n("Helge Deller"), i18n("Original Maintainer"), QStringLiteral("deller@gmx.de"));
-    about->addCredit(i18n("Brian Paul"), i18n("Author of glxinfo Mesa demos (http://www.mesa3d.org)"));
+    about->addCredit(i18n("Brian Paul"), i18n("Author of glxinfo Mesa demos (https://www.mesa3d.org)"));
     setAboutData(about);
 }
 
